# EDA-NIf (EDA NIfTI)
[![Contributor Covenant](https://img.shields.io/badge/contributor%20covenant-v2.0%20adopted-black.svg)](code_of_conduct.md)
[![Python Version](https://img.shields.io/badge/python-3.6%2C3.7%2C3.8-black.svg)](code_of_conduct.md)
![Pypi Version](https://img.shields.io/pypi/v/edanif.svg)
![Code convention](https://img.shields.io/badge/code%20convention-pep8-black)

Tool for *Exploratory Data Analysis of Neuroimaging Informatics Technology Initiative(NIfTI) format* <br>
`EDA-NIf` creates a dataframe containing meta information of NIfTi file format and provides several useful functions.

<br>

# Installation
  ```cmd
  pip install edanif
  ```
<Br>

# Tutorial
We provide tutorial notebooks for all the features we offer. We plan to provide additional docstrings or documentation from the official distribution version (major version 1 or higher).

1. Main-tutorials: https://github.com/DSDanielPark/EDA-NIf/blob/main/tutorials/edanif_tutorial.ipynb
2. Sub-tutorial-folder: https://github.com/DSDanielPark/EDA-NIf/tree/main/tutorials

<br>
<br>

# Main Feature
If you enter only the top-level folder containing nifti files, you can get a data frame for all nifti files.

<br>

# References
[1] NiBabel https://nipy.org/nibabel/


### Contacts
Maintainer: [Daniel Park, South Korea](https://github.com/DSDanielPark) 
e-mail parkminwoo1991@gmail.com
